# Generated by Django 2.2 on 2023-02-10 14:30

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django', '0008_auto_20230210_1029'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='documentitem',
            name='document',
        ),
        migrations.AlterField(
            model_name='templateitem',
            name='template',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='items', to='django.Template'),
        ),
        migrations.DeleteModel(
            name='Document',
        ),
        migrations.DeleteModel(
            name='DocumentItem',
        ),
    ]



# Generated by Django 2.2 on 2022-02-08 15:29

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Log',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('ref', models.CharField(default='', max_length=64)),
                ('model', models.CharField(default='', max_length=64)),
                ('date', models.DateTimeField(auto_now_add=True, null=True)),
                ('diff', models.TextField(default='')),
                ('action', models.CharField(default='', max_length=64)),
                ('transaction', models.CharField(default='', max_length=64, null=True)),
                ('user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='LogItem',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.CharField(default='', max_length=128)),
                ('old', models.CharField(default='', max_length=128, null=True)),
                ('new', models.CharField(default='', max_length=128, null=True)),
                ('log', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='items', to='django.Log')),
            ],
        ),
    ]
